import * as scannerJS from './js/jsqrscanner.nocache.js';

class JsQRScanner
{
  private scanner: any;

  public constructor()
  {
    if (!g.JsQRScanner)
    {
      throw new Error('JsQRScanner is not ready yet!');
    }

    this.scanner = new g.JsQRScanner(s => this.handleScannedText(s));
  }

  private handleScannedText(scannedText: string): void
  {
    if (this.onQRCodeScanned)
    {
      this.onQRCodeScanned(scannedText);
    }
  }

  public onQRCodeScanned?(scannedText: string): void;
}

export async function createJsQRScanner(): Promise<JsQRScanner>
{
  return new Promise<JsQRScanner>((resolve, reject) => 
  {
    CallWhenQRSacannerReady(() =>
    {
      const scanner = new JsQRScanner();
      resolve(scanner);
    });
  });
}

const g: any = window;
type TOnReady = () => void;
const callbacks: TOnReady[] = [];

function CallWhenQRSacannerReady(cb: TOnReady): void
{
  if (g.JsQRScanner)
  {
    cb();
  }
  else
  {
    callbacks.push(cb);
  }
}

function JsQRScannerReady()
{
  if (callbacks.length > 0)
  {
    callbacks.forEach(cb => cb());
    callbacks.splice(0, callbacks.length);
  }
}

if (scannerJS)
{
  g.JsQRScannerReady = JsQRScannerReady;
}

